* Extract and Label Variables to Merge into Master Dataset on Business Practices
clear
set mem 300m

cd C:\Users\wb200090\Dropbox\DavidMcKenzie\otherresearch\Bangladesh\

*** Missing Data
* GPS coordinates
* All front matter - firm name, address, etc.
* GPS coords of tax offices


use informality_data.dta

* Merge in GPS data and firm name etc.
sort slno
merge slno using gprs_informality_survey_bd.dta
drop _merge

sort dist
merge dist using sampleweights.dta
tab _merge

* Generate survey weights
gen totemployee=q1_12a5a+1
gen weight=classi13employee if totemployee>=1 & totemployee<=3
replace weight=classii49 if totemployee>=4 & totemployee<=9
replace weight=classiii1049 if totemployee>=10 & totemployee<=49
replace weight=classiv50 if totemployee>=50

svyset [pw=weight]


* GPS distances to TL, VAT and Tax offices
gen double firmlat=real(gpslatitue)
gen double firmlon=real(gpslong)
gen lat=firmlat
gen lon=firmlon
* correct errors
replace lat=24.886 if lat==24886
replace lat=24.00522 if lat==2400522
replace lon=89.21786 if lon==8921786
globdist kmToTLoffice, lat0(lat) lon0(lon) latvar(tl_office_latitude__n_) lonvar(tl_office_longitude__e_) 
globdist kmToVAToffice, lat0(lat) lon0(lon) latvar(vat_office_latitude__n_) lonvar(vat_office_longitude__e_) 
globdist kmTotaxoffice, lat0(lat) lon0(lon) latvar(tax_office_latitude__n_) lonvar(tax_office_longitude__e_) 
gen ldistTL=log(kmToTLoffice)
gen ldistVAT=log(kmToVAToffice)
gen ldisttax=log(kmTotaxoffice)

* Nature of business
gen manuf=nob==1
gen services=nob==2
gen trade=nob==3

* Geography
gen dhaka=dist=="DHAKA"
gen chittagong=dist=="CHITTAGONG"
gen lowincidence=dist=="SYLHET"|dist=="COX'S BAZAR"|dist=="NOAKHALI"|dist=="COMILLA"|dist=="TANGAIL"

*** Owner characteristics
gen male=gnd==1
replace male=. if gnd==.
gen normalhoursworked=q1_3b
gen ownerage=q1_13
gen married=q1_15==2
gen ednyears=q2_2
gen poorwhenyoung=q2_8==1
gen riskaversion=q9_1
gen digitspan=q9_2

*** Firm characteristics
* Ownership status
tab q1_1
gen soleproprietor=q1_1==1
* Site
gen informallocal=q1_4<=3|q1_4==5|q1_4==6

* Land title
gen landtitle=q1_7==1

* Age of firm
gen ageoffirm=2010-q1_11y
replace ageoffirm=. if q1_11y==999

* Workers
gen paidworkers=q1_12a1a+q1_12a2a

* Bank account
gen businessbankaccount=q3_2==1 & q3_3==1
gen overdraft=q3_4a==1
gen creditcard=q3_4b==1
gen chequeaccount=q3_4c==1
gen everprivateloan=q3_5a1==1
gen customerpaysbycheque=q3_8==1

* Assets
gen totalassets=q4_1a7
gen totalnonland=q4_1a7-q4_1a5
gen inventories=q4_4
replace inventories=0 if q4_3==2
gen allassets=totalassets+inventories
gen allassetsnonland=totalnonland+inventories

* use of assets
gen usecellphone=q4_2a==1
gen usecomputer=q4_2b==1

* paid taxes as expense in last month
gen paytaxes=q4_5f>0 & q4_5f~=.

* Sales
gen sales2009=q4_7
replace sales2009=. if q4_7==999
gen sales2008=q4_8
replace sales2008=. if q4_8==999
gen profitslastmonth=q4_10

* Exports
gen exports=q4_12>0 & q4_12~=.
gen exports2=(q10_1d>0 & q10_1d~=.)|(q10_1e>0 & q10_1e~=.)

* Innovation
gen productinnovation=q5_1==1
gen productimprovement=q5_3==1
gen processinnovation=q5_4==1
gen website=q5_6a==1
gen email=q5_6b==1

* Informality
gen tradelicense=q6_1==1
gen yearsinbusinessforTL=q6_1a
gen taxID=q6_12==1
gen yearsinbusinessforTIN=q6_12a
gen VAT=q6_21==1
gen issuesalesreceipt=q6_21c>0 & q6_21c~=.
gen businessassn=q6_24_b==1
gen chamberofcommerce=q6_24_c==1
gen paymentstopolice=q6_26a==1
gen paymenttomastan=q6_26b==1
gen municipalinspect=q6_10a>0
gen vatinspect=q6_10b>0
gen taxinspect=q6_10c>0
gen laborinspect=q6_10d>0
egen wardinspectmunicipal=mean(municipalinspect), by(ward)
egen wardinspectvat=mean(vatinspect), by(ward)
egen wardinspecttax=mean(taxinspect), by(ward)
egen wardinspectlabor=mean(laborinspect), by(ward)


gen usecreditcard=q4_2c==1
gen usefax=q4_2d==1


*** Business practices scorecard

set more off


foreach x of varlist q7_1a-q7_4g q7_5-q7_9 q7_10-q7_27_d q7_27_e-q7_28 {
des `x'
replace `x' = 0 if `x'==2 
replace `x' = . if `x'>100
}

foreach x of varlist q7_1a-q7_1e  {
des `x'
replace `x' = 0 if `x'==99 
}

foreach x of varlist q7_4a-q7_4f   { 
replace `x' = 0 if q7_3==0
}


***** Labelling and Saving of Variables for Export to Master Data Set
gen firmid=slno
gen bangladesh=1
gen round=1
gen ownershipstatus=q1_1
gen ownershours=q1_3a
gen startedbusiness=q1_8==1
gen monthlysales=q4_6
gen annualsales=q4_7 if q4_7~=999
gen monthlyprofit=q4_10
gen municipalregister=tradelicense
gen taxregister=taxID
gen capitalstock=totalassets
gen bp_m1=q7_1a
gen bp_m2=q7_1b
gen bp_m3=q7_1c
gen bp_m4=q7_1d
gen bp_m5=q7_1e
gen bp_m6=q7_2
gen bp_m7=q7_3
gen bp_b1=q7_6
gen bp_b2=q7_7
gen bp_b3=0 if q7_10==4
replace bp_b3=1 if q7_10<=3
replace bp_b3=1 if q7_8==0
foreach x of varlist q7_16-q7_18  { 
replace `x' = 0 if q7_15==0
}
gen bp_r1=q7_15
gen bp_r2=q7_16
gen bp_r3=q7_17
gen bp_r4=q7_18
gen bp_r5=q7_19
gen bp_r6=q7_20
gen bp_r7=q7_21
gen bp_r8=q7_23 
gen bp_f1=q7_24==4
gen bp_f2=q7_25
gen bp_f3=1 if q7_25a==4
replace bp_f3=0 if q7_25a<=3|q7_25==0
gen bp_f4=q7_26
foreach x of varlist q7_27_a-q7_27_d  { 
replace `x' = 0 if q7_27_f==1|`x'==.
}
gen bp_f5=q7_27_a
gen bp_f6=q7_27_b
gen bp_f7=q7_27_c
gen bp_f8=q7_27_d
gen competition1=q10_1a 
gen competition2=q10_2 if q10_2~=999
gen competition3=q10_4==1
gen competition4=q10_6==1
gen detailedindustry=q1_2
label var detailedindustry "Detailed industry code"
label var competition1 "Percent of sales from within small local area"
label var competition2 "Number of firms in same business line in your area"
label var competition3 "Most important competitor is located within 1 km of business"
label var competition4 "Would take less than a day for customer to replace you"
label var bp_m1 "Marketing 1: Visited competitor's business to see prices"
label var bp_m2 "Marketing 2: Visited competitor's business to see products"
label var bp_m3 "Marketing 3: Asked existing customers what other products they should offer"
label var bp_m4 "Marketing 4: Talked with former customer to see why stopped buying"
label var bp_m5 "Marketing 5: Asked supplier what products selling well"
label var bp_m6 "Marketing 6: Used a special offer to attract customers"
label var bp_m7 "Marketing 7: Have done advertising in last 6 months"
label var bp_b1 "Buying & Stock Control 1: negotiate for lower price"
label var bp_b2 "Buying & Stock Control 2: compare alternate suppliers"
label var bp_b3 "Buying & Stock Control 3: Don't run out of stock frequently"
label var bp_r1 "Costing & Record Keeping 1: Keep written records"
label var bp_r2 "Costing & Record Keeping 2: record every purchase and sale"
label var bp_r3 "Costing & Record Keeping 3: can use records to know cash on hand"
label var bp_r4 "Costing & Record Keeping 4: use records to know whether sales of product increase or decrease"
label var bp_r5 "Costing & Record Keeping 5: worked out cost of each main product"
label var bp_r6 "Costing & Record Keeping 6: know which goods make most profit per item"
label var bp_r7 "Costing & Record Keeping 7: have a written budget for monthly expenses"
label var bp_r8 "Costing & Record Keeping 8: have records that could document ability to pay to bank"
label var bp_f1 "Financial Planning 1: review financial performance monthly"
label var bp_f2 "Financial Planning 2: have sales target for next year"
label var bp_f3 "Financial Planning 3: compare sales goal to target monthly"
label var bp_f4 "Financial Planning 4: have a budget of costs for next year"
label var bp_f5 "Financial Planning 5: prepare profit and loss statement"
label var bp_f6 "Financial Planning 6: prepare cashflow statement"
label var bp_f7 "Financial Planning 7: prepare balance sheet"
label var bp_f8 "Financial Planning 8: prepare income and expenditure statement"
label var bangladesh "Bangladesh country dummy"
label var weight "Survey weight"
label var round "Survey round"
label var male "Owner is male"
label var manuf "Sector is manufacturing"
label var trade "Sector is trade"
label var services "Sector is services"
label var ownershipstatus "Ownership Status"
label var ownershours "Hours worked by owner in last week"
label var startedbusiness "Owner started business themselves"
label var ageoffirm "Firm age (years)"
label var paidworkers "Number of paid workers"
label var ownerage "Age of owner"
label var ednyears "Years of education of owner"
label var inventories "Value of inventories"
label var monthlysales "Sales in the last month"
label var annualsales "Sales in the last year"
label var monthlyprofit "Monthly profit"
label var municipalregister "Registered at Municipal Level"
label var taxregister "Registered for national taxes"
label var capitalstock "Capital stock"
label var digitspan "Digitspan recall"
label var firmid "Firm identification number"

gen excrate=68
label var excrate "Market exchange rate to USD (divide by this to get USD)"

#delimit ;
keep firmid bangladesh round weight male manuf trade services ownershipstatus ownershours
startedbusiness ageoffirm paidworkers ownerage ednyears inventories detailedind
monthlysales annualsales monthlyprofit municipalregister taxregister
capitalstock bp_m1-bp_f8 digitspan competition1-competition4 excrate;
#delimit cr

 save "C:\Users\wb200090\Dropbox\DavidMcKenzie\otherresearch\BusinesspracticesPaper\CleanedCountryFiles\Bangladesh_BP.dta", replace





