**** Business Practices Paper Analysis - Kenya

cd "C:\Users\wb200090\Dropbox\WED Data\DavidFilesdontdelete\CombinedData\
use "AllBaselineKenyaPublicUse.dta", clear


label define RegionLabel 1 "Kakamega"
label define RegionLabel 2 "Kisii", add
label define RegionLabel 3 "Embu", add
label define RegionLabel 4 "Kitui", add
label values region RegionLabel
label define TreatLabel 1 "Standard Invite"
label define TreatLabel 2 "Active Choice", add
label define TreatLabel 3 "Enhanced Active Choice", add
label values treattype TreatLabel
tab region treattype

*** Construct individual and business characteristics 

**** individual characteristics
gen above35=age>35
label var above35 "Aged above 35"
gen yearsedn=b_s1_16
replace yearsedn=b_s1_17 if b_s1_17~=.
label var yearsedn "Years of Schooling"
gen married=cond(b_s1_18==2,1,0) if b_s1_18~=.
label var married "Married"
gen haschildren=cond(b_s1_21>0 & b_s1_21<20,1,0) if b_s1_21<20
label var haschildren "Has a child"
gen child5under=cond(b_s1_22<=5,1,0) if haschildren~=.
label var child5under "Has a child of 5 and under"
replace b_s1_26c=. if b_s1_26c>20
replace b_s1_26b=. if b_s1_26b>20
gen hhsize=b_s1_26a+b_s1_26b+b_s1_26c
label var hhsize "Household Size"
gen highdiscountrate=b_s4_6<=800
label var highdiscountrate "High discount rate"
gen raven=b_s12_1_total_b if b_s12_1_total_b<=12
label var raven "Raven test score"
gen digitspan=3 if b_s13_1_a==2
replace digitspan=4 if b_s13_1_a==1
replace digitspan=5 if b_s13_1_b==1
replace digitspan=6 if b_s13_1_c==1
replace digitspan=7 if b_s13_1_d==1
replace digitspan=8 if b_s13_1_e==1
replace digitspan=9 if b_s13_1_f==1
replace digitspan=10 if b_s13_1_g==1
replace digitspan=11 if b_s13_1_h==1
label var digitspan "Digitspan recall"
gen previoustraining=cond(b_s7_1==1,1,0) if b_s7_1~=.
label var previoustraining "Owner has previously participated in business training"

**** Business characteristics
gen trade=b_business_nature==3
label var trade "Sector is retail"
gen services=b_business_nature==2
label var services "Sector is services"
gen manuf=b_business_nature==1

replace trade=. if b_business_nature==.
replace services=. if b_business_nature==.
replace manuf=. if b_business_nature==.
gen hoursworked=b_s1_5_a
replace hoursworked=. if b_s1_5_a>168
label var hoursworked "Weekly hours worked by owner in business"
gen ageoffirm=2013-b_s1_10_year
replace ageoffirm=. if b_s1_10_year<1950|b_s1_10_year>2013
label var ageoffirm "Age of firm in years"
gen b_keeprecords=b_s1_11==1
label var b_keeprecords "Keeps business records"
gen nonfamilyinbus=b_s1_13_a_6==1
label var nonfamilyinbus "Has a non-family member employee"
egen nonlandK=rsum(b_s5_1a_1- b_s5_1a_4)
gen inventories=b_s5_3 if b_s5_3~=999
replace inventories=0 if b_s5_2==2
gen totalK=nonlandK+inventories
label var totalK "Capital stock (excluding land and buildings)"

*** Associations between business practices and sales, profitability, etc.
gen salesweek=b_s5_6b
gen logsales=log(salesweek)
gen profitsweek=q16_profit
gen logprofits=log(profitsweek)

gen ownedcapital=b_s5_1a_1+b_s5_1a_2+b_s5_1a_3+b_s5_1a_4+b_s5_1a_5+b_s5_1a_6
gen ownedcapital_miss=ownedcapital==0
replace ownedcapital=0 if ownedcapital==.
gen laborhours=b_s1_5_a
gen laborhours_miss=laborhours==.
replace laborhours=0 if laborhours==.
sum laborhours, de
replace laborhours=r(p99) if laborhours>r(p99) & laborhours~=.
gen logK=log(ownedcapital)
gen noK=ownedcapital==0
replace logK=0 if noK==1

* labor hours of other workers
gen paidlaborhours=0
replace paidlaborhours=paidlaborhours+b_s1_13_e_1 if b_s1_13_f_1<=2 & b_s1_13_e_1<=120
replace paidlaborhours=paidlaborhours+b_s1_13_e_2 if b_s1_13_f_2<=2 & b_s1_13_e_2<=120
replace paidlaborhours=paidlaborhours+b_s1_13_e_3 if b_s1_13_f_3<=2 & b_s1_13_e_3<=120
replace paidlaborhours=paidlaborhours+b_s1_13_e_4 if b_s1_13_f_4<=2 & b_s1_13_e_4<=120
replace paidlaborhours=paidlaborhours+b_s1_13_e_5 if b_s1_13_f_5<=2 & b_s1_13_e_5<=300
replace paidlaborhours=paidlaborhours+b_s1_13_e_6 if b_s1_13_f_6<=2 & b_s1_13_e_6<=300


gen round=1
gen kenya=1
label var kenya "Kenya dummy variable"
gen male=0
gen double firmid=respondent_id
gen ownershipstatus=b_s1_1
gen ownershours=laborhours
gen startedbusiness=b_s1_7==1
replace startedbusiness=. if b_s1_7==.
gen paidworkers=0
replace paidworkers=paidworkers+b_s1_13_b_1 if b_s1_13_f_1<=2
replace paidworkers=paidworkers+b_s1_13_b_2 if b_s1_13_f_2<=2
replace paidworkers=paidworkers+b_s1_13_b_3 if b_s1_13_f_3<=2
replace paidworkers=paidworkers+b_s1_13_b_4 if b_s1_13_f_4<=2
replace paidworkers=paidworkers+b_s1_13_b_5 if b_s1_13_f_5<=2
replace paidworkers=paidworkers+b_s1_13_b_6 if b_s1_13_f_6<=2
gen ownerage=age
gen ednyears=yearsedn
gen monthlysales=salesweek*4
gen monthlyprofit=profitsweek*4
gen excrate=85
gen municipalregister=b_s1_3==1
gen capitalstock=b_s5_1a_7
label var excrate "Market exchange rate to USD (divide by this to get USD)"
gen father_owned_business=b_s3_3==1
gen mother_owned_business=b_s3_5==1
gen discountrate1=(1000-b_s4_6)/1000
gen discountrate2=(1000-b_s13_2)/1000
gen hyperbolic=discountrate2>discountrate1 & discountrate2~=.
gen competition2=b_s8_1 if b_s8_1~=999

foreach x of varlist b_s9_1a-b_s9_4h  b_s9_4i b_s9_5 b_s9_6-b_s9_9 b_s9_10-b_s9_13 b_s9_14-b_s9_22 b_s9_23-b_s9_26 { 
replace `x'=. if `x'>100
replace `x'=0 if `x'==2
replace `x'=0 if `x'==. & b_s9_1a~=.
}
gen bp_m1=b_s9_1a
gen bp_m2=b_s9_1b
gen bp_m3=b_s9_1c
gen bp_m4=b_s9_1d
gen bp_m5=b_s9_1e
gen bp_m6=b_s9_2
gen bp_m7=b_s9_3
gen bp_b1=b_s9_6
gen bp_b2=b_s9_7
gen bp_b3=0 if b_s9_10==4
replace bp_b3=1 if b_s9_10<=3
replace bp_b3=1 if b_s9_8==0
foreach x of varlist b_s9_15-b_s9_17  { 
replace `x' = 0 if b_s9_14==0
}
gen bp_r1=b_s9_14
gen bp_r2=b_s9_15
gen bp_r3=b_s9_16
gen bp_r4=b_s9_17
gen bp_r5=b_s9_18
gen bp_r6=b_s9_19
gen bp_r7=b_s9_20
gen bp_r8=b_s9_22 
gen bp_f1=b_s9_23==4
replace b_s9_24=1 if b_s9_24==3|b_s9_24==4
gen bp_f2=b_s9_24
gen bp_f3=1 if b_s9_24a==4
replace bp_f3=0 if b_s9_24a<=3|b_s9_24==0
gen bp_f4=b_s9_25
* note Kenya data didn't allow for multiple responses on these statements. 
/*
foreach x of varlist b_s9_26_1-b_s9_26_4  { 
replace `x' = 0 if b_s9_26_6==1|`x'==.
}
gen bp_f5=b_s9_26_1
gen bp_f6=b_s9_26_2
gen bp_f7=b_s9_26_3
gen bp_f8=b_s9_26_4
*/

gen detailedindustry=1 if b_s1_2_2_2_coded1==1
for num 2/3: replace detailedindustry=X if b_s1_2_2_2_codedX==1
for num 5/20: replace detailedindustry=X if b_s1_2_2_2_codedX==1
for num 22/23: replace detailedindustry=X if b_s1_2_2_2_codedX==1
for num 25/35: replace detailedindustry=X if b_s1_2_2_2_codedX==1
label var detailedindustry "Detailed industry coding"

label var discountrate1 "Discount rate today vs one month (higher = more impatient)"
label var discountrate1 "Discount rate 5 months vs 6 months (higher = more impatient)"
label var hyperbolic "Hyperbolic discounter"
label var father_owned_business "Father owned a business"
label var mother_owned_business "Mother owned a business"
*label var competition1 "Percent of sales from within small local area"
label var competition2 "Number of firms in same business line in your area"
*label var competition3 "Most important competitor is located within 1 km of business"
*label var competition4 "Would take less than a day for customer to replace you"
label var bp_m1 "Marketing 1: Visited competitor's business to see prices"
label var bp_m2 "Marketing 2: Visited competitor's business to see products"
label var bp_m3 "Marketing 3: Asked existing customers what other products they should offer"
label var bp_m4 "Marketing 4: Talked with former customer to see why stopped buying"
label var bp_m5 "Marketing 5: Asked supplier what products selling well"
label var bp_m6 "Marketing 6: Used a special offer to attract customers"
label var bp_m7 "Marketing 7: Have done advertising in last 6 months"
label var bp_b1 "Buying & Stock Control 1: negotiate for lower price"
label var bp_b2 "Buying & Stock Control 2: compare alternate suppliers"
label var bp_b3 "Buying & Stock Control 3: Don't run out of stock frequently"
label var bp_r1 "Costing & Record Keeping 1: Keep written records"
label var bp_r2 "Costing & Record Keeping 2: record every purchase and sale"
label var bp_r3 "Costing & Record Keeping 3: can use records to know cash on hand"
label var bp_r4 "Costing & Record Keeping 4: use records to know whether sales of product increase or decrease"
label var bp_r5 "Costing & Record Keeping 5: worked out cost of each main product"
label var bp_r6 "Costing & Record Keeping 6: know which goods make most profit per item"
label var bp_r7 "Costing & Record Keeping 7: have a written budget for monthly expenses"
label var bp_r8 "Costing & Record Keeping 8: have records that could document ability to pay to bank"
label var bp_f1 "Financial Planning 1: review financial performance monthly"
label var bp_f2 "Financial Planning 2: have sales target for next year"
label var bp_f3 "Financial Planning 3: compare sales goal to target monthly"
label var bp_f4 "Financial Planning 4: have a budget of costs for next year"
*label var bp_f5 "Financial Planning 5: prepare profit and loss statement"
*label var bp_f6 "Financial Planning 6: prepare cashflow statement"
*label var bp_f7 "Financial Planning 7: prepare balance sheet"
*label var bp_f8 "Financial Planning 8: prepare income and expenditure statement"
*label var weight "Survey weight"
label var round "Survey round"
label var male "Owner is male"
label var manuf "Sector is manufacturing"
label var trade "Sector is trade"
label var services "Sector is services"
label var ownershipstatus "Ownership Status"
label var ownershours "Hours worked by owner in last week"
label var startedbusiness "Owner started business themselves"
label var ageoffirm "Firm age (years)"
label var paidworkers "Number of paid workers"
label var ownerage "Age of owner"
label var ednyears "Years of education of owner"
label var inventories "Value of inventories"
label var monthlysales "Sales in the last month"
*label var annualsales "Sales in the last year"
label var monthlyprofit "Monthly profit"
label var municipalregister "Registered at Municipal Level"
*label var taxregister "Registered for national taxes"
label var capitalstock "Capital stock"
label var digitspan "Digitspan recall"
label var raven "Raven test score"
label var firmid "Firm identification number"

#delimit ;
keep firmid kenya round  male manuf trade services ownershipstatus ownershours
startedbusiness ageoffirm paidworkers ownerage ednyears inventories
monthlysales monthlyprofit municipalregister detailedindustry
capitalstock bp_m1-bp_f4 digitspan raven competition2 excrate
father_owned_business mother_owned_business discountrate1 discountrate2 hyperbolic;
#delimit cr
*variables not in this dataset
* annualsales taxregister competition1 competition3 competition4 weight
sort firmid round
save "C:\Users\wb200090\Dropbox\DavidMcKenzie\otherresearch\BusinesspracticesPaper\Kenya_BP.dta", replace


*************** Second Round Kenya data ***************
use "C:\Users\wb200090\Dropbox\WED Data\DavidFilesdontdelete\CombinedData\Round2\CleanedRound2Merged.dta", clear

*** drop those not in study
drop if notinbaseline==1
gen survives=1 if stillinbiz==1
replace survives=0 if stillinbiz==2
* individuals who died are not in business
replace survives=0 if reasonattr=="6"
replace survives=1 if sec2_3<=2
replace survives=0 if sec2_3==3
* individuals who claim never to have run a business 
replace survives=0 if sec2_2_=="-777"
replace survives=0 if reasonattr_a=="BUSY AND CLOSED BUSINES"

**** Treatment regression
gen spillovertreat=r1_treated==0 & r1_treatedmarket==1
replace r1_treated=0 if r1_treatedmarket==0

**** Sales in the last week
gen salesweek=sec5_8_
* cleaning
replace salesweek=. if sec5_8_==-999|sec5_8_==-888|sec5_8_==-555|sec5_8_==-666|(sec5_8_>0.9 & sec5_8_<1)
* sales are zero if they were closed that day
replace salesweek=0 if sec5_8_==-444|(sec5_8_>0.4 & sec5_8_<0.5)
replace salesweek=. if salesweek<0
* replace with range answers if only answered those
replace salesweek=500 if salesweek==. & sec5_8a==1
replace salesweek=1250 if salesweek==. & sec5_8a==2
replace salesweek=1750 if salesweek==. & sec5_8a==3
replace salesweek=2250 if salesweek==. & sec5_8a==4
replace salesweek=2750 if salesweek==. & sec5_8a==5
replace salesweek=3500 if salesweek==. & sec5_8a==6
replace salesweek=4500 if salesweek==. & sec5_8a==7
replace salesweek=6000 if salesweek==. & sec5_8a==8
replace salesweek=8500 if salesweek==. & sec5_8a==9
sum salesweek if salesweek>=10000 & salesweek~=., de
gen medsalesw=r(p50)
replace salesweek=medsalesw if salesweek==. & sec5_8a==10
* sales are then zero for firms which don't survive
replace salesweek=0 if survives==0
label var salesweek "Sales in last week, first follow-up"
* truncate at 99th percentile, as per pre-analysis plan
sum salesweek, de
replace salesweek=r(p99) if salesweek>r(p99) & salesweek~=.

*** Average weekly profits over last 2 weeks
gen prof1=sec5_9_
replace prof1=. if prof1==-999|prof1==-888|prof1==-555|(prof1>0.8 & prof1<1)
replace prof1=0 if prof1==-444|(prof1>0.4 & prof1<0.5)
replace prof1=250 if prof1==. & sec5_9a==1
replace prof1=750 if prof1==. & sec5_9a==2
replace prof1=1250 if prof1==. & sec5_9a==3
replace prof1=1750 if prof1==. & sec5_9a==4
replace prof1=2250 if prof1==. & sec5_9a==5
replace prof1=2750 if prof1==. & sec5_9a==6
replace prof1=3500 if prof1==. & sec5_9a==7
replace prof1=4500 if prof1==. & sec5_9a==8
replace prof1=6000 if prof1==. & sec5_9a==9
replace prof1=8500 if prof1==. & sec5_9a==10
replace prof1=12500 if prof1==. & sec5_9a==11
sum prof1 if prof1>=15000 & prof1~=., de
replace prof1=r(p50) if prof1==. & sec5_9a==12
replace prof1=0 if survives==0
gen prof2=sec5_9b
replace prof2=. if prof2==-999|prof2==-888|prof2==-555|(prof2>0.8 & prof2<1)
replace prof2=0 if prof2==-444|(prof2>0.4 & prof2<0.5)
replace prof2=250 if prof2==. & sec5_9bi==1
replace prof2=750 if prof2==. & sec5_9bi==2
replace prof2=1250 if prof2==. & sec5_9bi==3
replace prof2=1750 if prof2==. & sec5_9bi==4
replace prof2=2250 if prof2==. & sec5_9bi==5
replace prof2=2750 if prof2==. & sec5_9bi==6
replace prof2=3500 if prof2==. & sec5_9bi==7
replace prof2=4500 if prof2==. & sec5_9bi==8
replace prof2=6000 if prof2==. & sec5_9bi==9
replace prof2=8500 if prof2==. & sec5_9bi==10
replace prof2=12500 if prof2==. & sec5_9bi==11
sum prof2 if prof2>=15000 & prof2~=., de
replace prof2=r(p50) if prof2==. & sec5_9bi==12
replace prof2=0 if survives==0

gen profitsweek=(prof1 + prof2)/2 if prof1~=. & prof2~=.
replace profitsweek=prof1 if prof2==.
replace profitsweek=prof2 if prof1==.
sum profitsweek, de
replace profitsweek=r(p99) if profitsweek>r(p99) & profitsweek~=.
label var profitsweek "Average weekly profits over last 2 weeks, first follow-up"

foreach x of varlist sec7_1a-sec7_4h sec7_14-sec7_20 sec7_22 sec7_6_ sec7_7 { 
replace `x'=. if `x'>100
replace `x'=0 if `x'==2
replace `x'=0 if `x'==. & sec7_1a~=.
}
gen bp_m1=sec7_1a
replace bp_m1=0 if sec7_1a==3
gen bp_m2=sec7_1b
replace bp_m2=0 if sec7_1b==3
gen bp_m3=sec7_1c
replace bp_m3=. if sec7_1c==3
gen bp_m4=sec7_1d
replace bp_m4=0 if sec7_1d==3
replace bp_m4=. if sec7_1d==4
gen bp_m5=sec7_1e
replace bp_m5=0 if sec7_1e==3
replace bp_m5=. if sec7_1e==4
gen bp_m6=sec7_2_ if sec7_2_<=1
gen bp_m7=sec7_3_ if sec7_3_<=1

gen bp_b1=sec7_6_ if sec7_6_<=1
gen bp_b2=sec7_7_ if sec7_7_<=1
gen bp_b3=0 if sec7_10_==4
replace bp_b3=1 if sec7_10_<=3
replace bp_b3=1 if sec7_8_==0

foreach x of varlist sec7_15_-sec7_17_  { 
replace `x' = 0 if sec7_14_==0
}
foreach x of varlist sec7_14_-sec7_22_  { 
replace `x' = . if `x'>1
}
gen bp_r1=sec7_14_
gen bp_r2=sec7_15_
gen bp_r3=sec7_16_
gen bp_r4=sec7_17_
gen bp_r5=sec7_18_
gen bp_r6=sec7_19_
gen bp_r7=sec7_20_
gen bp_r8=sec7_22_ 
gen bp_f1=sec7_23_==4
replace bp_f1=. if sec7_23_==.
gen bp_f2=1 if sec7_24_ ==1
replace bp_f2=0 if sec7_24_==2
gen bp_f3=1 if sec7_24a==4
replace bp_f3=0 if sec7_24a<=3|bp_f2==0
replace sec7_25_=0 if sec7_25_==2
gen bp_f4=sec7_25_ if sec7_25<=1 

foreach x of varlist sec7_26_1-sec7_26_4  { 
replace `x' = 0 if sec7_26_5==1|(`x'==. & bp_r1~=.)|(`x'>1 & bp_r1~=.)
replace `x' = . if bp_f4==. & bp_m1==. & bp_m2==.
}
gen bp_f5=sec7_26_1
gen bp_f6=sec7_26_2
gen bp_f7=sec7_26_3
gen bp_f8=sec7_26_4


label var bp_m1 "Marketing 1: Visited competitor's business to see prices"
label var bp_m2 "Marketing 2: Visited competitor's business to see products"
label var bp_m3 "Marketing 3: Asked existing customers what other products they should offer"
label var bp_m4 "Marketing 4: Talked with former customer to see why stopped buying"
label var bp_m5 "Marketing 5: Asked supplier what products selling well"
label var bp_m6 "Marketing 6: Used a special offer to attract customers"
label var bp_m7 "Marketing 7: Have done advertising in last 6 months"
label var bp_b1 "Buying & Stock Control 1: negotiate for lower price"
label var bp_b2 "Buying & Stock Control 2: compare alternate suppliers"
label var bp_b3 "Buying & Stock Control 3: Don't run out of stock frequently"
label var bp_r1 "Costing & Record Keeping 1: Keep written records"
label var bp_r2 "Costing & Record Keeping 2: record every purchase and sale"
label var bp_r3 "Costing & Record Keeping 3: can use records to know cash on hand"
label var bp_r4 "Costing & Record Keeping 4: use records to know whether sales of product increase or decrease"
label var bp_r5 "Costing & Record Keeping 5: worked out cost of each main product"
label var bp_r6 "Costing & Record Keeping 6: know which goods make most profit per item"
label var bp_r7 "Costing & Record Keeping 7: have a written budget for monthly expenses"
label var bp_r8 "Costing & Record Keeping 8: have records that could document ability to pay to bank"
label var bp_f1 "Financial Planning 1: review financial performance monthly"
label var bp_f2 "Financial Planning 2: have sales target for next year"
label var bp_f3 "Financial Planning 3: compare sales goal to target monthly"
label var bp_f4 "Financial Planning 4: have a budget of costs for next year"
label var bp_f5 "Financial Planning 5: prepare profit and loss statement"
label var bp_f6 "Financial Planning 6: prepare cashflow statement"
label var bp_f7 "Financial Planning 7: prepare balance sheet"
label var bp_f8 "Financial Planning 8: prepare income and expenditure statement"

label var r1_treated "Treatment Group for Female Business Training Kenya"
gen survival=survives
label var survival "Business is surviving"
gen round=2
gen double firmid=respid
gen monthlyprofit=profitsweek*4
gen monthlysales=salesweek*4
gen kenya=1
gen excrate=86
keep firmid round r1_treated r1_everattends monthlyprofit monthlysales survival kenya bp_m1-bp_f8 excrate



sort firmid 
append using "C:\Users\wb200090\Dropbox\DavidMcKenzie\otherresearch\BusinesspracticesPaper\Kenya_BP.dta"

drop if firmid==20030011 
sort firmid round

label var r1_treated "Randomly Assigned to Training Treatment"
label var r1_everattends "Attends Business Training after being assigned"
rename r1_treated training_treat
rename r1_everattends training_attend
save "C:\Users\wb200090\Dropbox\DavidMcKenzie\otherresearch\BusinesspracticesPaper\CleanedCountryFiles\Kenya_BP.dta", replace




























