**** Business Plan Paper Replication File Using Constructed Dataset

*** Set directory
cd C:\Users\wb200090\Dropbox\DavidMcKenzie\otherresearch\BusinesspracticesPaper\


*******************************************************

*** Using Master File
use BusinessPracticesReplicationdata.dta, clear

set more off
* replace missings that were zeroes
egen tscore=rmean(bp_m1-bp_f8)
foreach var of varlist bp_f1 bp_f5 bp_f6 bp_f7 bp_f8 {
replace `var'=. if tscore==0 & bp_m1==.
}

** Create Indices of Business Practices
egen marketingscore=rmean(bp_m1 bp_m2 bp_m3 bp_m4 bp_m5 bp_m6 bp_m7)
label var marketingscore "Proportion of marketing practices used"
egen stockscore=rmean(bp_b1 bp_b2 bp_b3)
label var stockscore "Proportion of buying and stock control practices used"
egen recordscore=rmean(bp_r1 bp_r2 bp_r3 bp_r4 bp_r5 bp_r6 bp_r7 bp_r8)
label var recordscore "Proportion of record-keeping practices used"
egen planningscore=rmean(bp_f1-bp_f8)
label var planningscore "Proportion of financial planning practices used"
egen totalscore=rmean(bp_m1-bp_f8)
label var totalscore "Business Practices Score"



*** round totalscore to nearest 0.05 to help deal visually with missing data
gen totalscore1=round(totalscore,0.05)

****** Figure 1:  Wide Variation in Business Practices within Countries
histogram totalscore1 if round==1, discrete by(country)
* used graphics editor in Stata, with Figure1recorder.grec, to produce \output\new\Figure1.gph and .wmf

******* Convert all monetary figures to current USD
replace monthlysales=monthlysales/excrate
replace monthlyprofit=monthlyprofit/excrate
replace inventories=inventories/excrate
replace annualsales=annualsales/excrate
replace capitalstock=capitalstock/excrate


**** Table 1: Summary Statistics 
gen countrynum=1 if bangladesh==1
replace countrynum=2 if chile==1
replace countrynum=3 if ghana==1
replace countrynum=4 if kenya==1
replace countrynum=5 if mexico==1
replace countrynum=6 if nigeria==1
replace countrynum=7 if srilanka==1



* Summary Stats Table
mat y = J(27,9,.)	
local j=1
foreach var of varlist male ownerage ednyears digitspan raven father_owned_business mother_owned_business trade manuf ageoffirm paidworkers monthlysales monthlyprofit capitalstock taxregister competition3 competition4 totalscore marketingscore stockscore recordscore planningscore {
sum `var' if round==1
mat y[`j',1] = r(mean)
mat y[`j',2] = r(sd)
forval x=1/7 {
local k=`x'+2
sum `var' if countrynum==`x' & round==1
mat y[`j',`k'] = r(mean)
}
local j=`j'+1
}
sum monthlysales if round==1, de
mat y[23,1]=r(p50)
forval x=1/7 {
local k=`x'+2
sum monthlysales if round==1 & countrynum==`x', de
mat y[23,`k'] = r(p50)
}
sum monthlyprofit if round==1, de
mat y[24,1]=r(p50)
forval x=1/7 {
local k=`x'+2
sum monthlyprofit if round==1 & countrynum==`x', de
mat y[24,`k'] = r(p50)
}
sum capitalstock if round==1, de
mat y[25,1]=r(p50)
forval x=1/7 {
local k=`x'+2
sum capitalstock  if round==1 & countrynum==`x', de
mat y[25,`k'] = r(p50)
}
sum paidworkers if round==1, de
mat y[26,1]=r(p50)
forval x=1/7 {
local k=`x'+2
sum paidworkers if round==1 & countrynum==`x', de
mat y[26,`k'] = r(p50)
}
sum totalscore if round==1
mat y[27,1] = r(N)
forval x=1/7 {
local k=`x'+2
sum totalscore if countrynum==`x' & round==1
mat y[27,`k'] = r(N)
}
mat rownames y = "Male" "Owner's Age" "Years of Educ" "Digitspan" "Raven test" "Father Owned a Business" "Mother Owned a Business" "Trade" "Manufacturing" "Firm age" "Number of Paid Workers" "Monthly Sales (USD)" "Monthly Profits (USD)" "Capital Stock (USD)" "Registered for Taxes" "Competitor within 1km" "Customer can replace easily" "Business Practice Score" "Marketing Score" "Buying and Stock Score" "Record-Keeping Score" "Financial Planning Score" "Median Sales (USD)" "Median Profits (USD)" "Median Capital Stock (USD)" "Median paid workers" "Number of Observations"
mat colnames y = "Overall Mean" "Overall SD" "Bangladesh" "Chile" "Ghana" "Kenya" "Nigeria" "Sri Lanka" "Mexico"
mat2txt, matrix(y) saving(Output\new\Table1SummaryStats.xls) replace


******* Figure 2: Stability of Practices over Time
gen baselinescore=totalscore if round==1
egen bscore=max(baselinescore), by(firmid country)

corr totalscore bscore if (country=="Kenya" & round==2)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3)|(country=="Ghana" & round==2)
spearman totalscore bscore if (country=="Kenya" & round==2)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3)|(country=="Ghana" & round==2)

* Restrict to group in each country not subject to business training
corr totalscore bscore if (country=="Kenya" & round==2 & training_treat==0)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3 & training_treat==0)|(country=="Ghana" & round==2)
spearman totalscore bscore if (country=="Kenya" & round==2 & training_treat==0)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3 & training_treat==0)|(country=="Ghana" & round==2)

twoway scatter totalscore bscore if (country=="Kenya" & round==2 & training_treat==0)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3 & training_treat==0)|(country=="Ghana" & round==2), jitter(5) jitterseed(123)
* edited with newFigure2recorder.grec

*********** Audit Data
egen mv_marketingscore=rmean(mv_m1 mv_m2 mv_m3 mv_m4 mv_m5 mv_m6 mv_m7)
label var mv_marketingscore "Proportion of marketing practices used (audit)"
egen mv_stockscore=rmean(mv_b1 mv_b2 mv_b3)
label var mv_stockscore "Proportion of buying and stock control practices used (audit)"
egen mv_recordscore=rmean(mv_r1 mv_r2 mv_r3 mv_r4 mv_r5 mv_r6 mv_r7 mv_r8)
label var mv_recordscore "Proportion of record-keeping practices used (audit)"
egen mv_planningscore=rmean(mv_f1-mv_f8)
label var mv_planningscore "Proportion of financial planning practices used (audit)"
egen mv_totalscore=rmean(mv_b1-mv_m7)
label var mv_totalscore "Business Practices Score (audit)"

corr totalscore mv_totalscore
spearman totalscore mv_totalscore
reg mv_totalscore totalscore
predict fittedscore, xb
sort totalscore
twoway (scatter mv_totalscore totalscore, jitter(5) jitterseed(123)) (line fittedscore totalscore totalscore)


*** Share of observations same in audit and survey by practice
foreach var in  m1  m2  m3  m4  m5  m6  m7  b1  b2  b3  r1  r2  r3  r4  r5  r6  r7  r8  f1 f2 f3 f4 f5 f6 f7 f8 {
gen `var'_different=abs(bp_`var'-mv_`var')
egen num_`var'_d=sum(`var'_different)
egen num_`var'_a=count(mv_`var') if bp_`var'~=.
gen per_diff_`var'=100*num_`var'_d/num_`var'_a
}
sum per_diff*

** Any training effect on difference between audit and survey
gen differencescore=mv_totalscore-totalscore
eststo clear
reg differencescore training_treat if srilanka==1, r
sum differencescore if e(sample)
estadd scalar mean=r(mean)
estadd scalar sd=r(sd)
eststo tablenA_1
#delimit ;
esttab tablenA_1 using Output\tablenA1.csv, replace depvar legend label nonumbers nogaps
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean sd, fmt(%9.0g %9.3f %9.3f) labels("Sample Size" "Mean Difference between Audit and Survey" "SD of Difference" )) 
	title("Table A1: Business Training Does Not Affect Reporting") addnotes("""") ;
#delimit cr



**************************
* Cross-sectional correlations between business practices and sales and profitability
gen logsales=log(monthlysales)
gen logprofit=log(monthlyprofit)

**** Figure 4: Sales
lpoly logsales totalscore if round==1, noscatter ci degree(1) bwidth(0.05) 
* edit in graph editor using Figure2recorder.grec, saved as Figure2_overall.gph 
lpoly logsales totalscore if round==1 & kenya==1, noscatter ci degree(1) bwidth(0.05)
* edit in graph editor using Figure2recorder.grec, saved as Figure2_kenya.gph 
lpoly logsales totalscore if round==1 & srilanka==1, noscatter ci degree(1) bwidth(0.05) 
* edit in graph editor using Figure2recorder.grec, saved as Figure2_srilanka.gph 
lpoly logsales totalscore if round==1 & bangladesh==1, noscatter ci degree(1) bwidth(0.05) 
* edit in graph editor using Figure2recorder.grec, saved as Figure2_bangladesh.gph 
lpoly logsales totalscore if round==1 & ghana==1, noscatter ci degree(1) bwidth(0.05) 
* edit in graph editor using Figure2recorder.grec, saved as Figure2_ghana.gph 
lpoly logsales totalscore if round==1 & mexico==1, noscatter ci degree(1) bwidth(0.05) 
* edit in graph editor using Figure2recorder.grec, saved as Figure2_mexico.gph 
lpoly logsales totalscore if round==1 & nigeria==1, noscatter ci degree(1) bwidth(0.05) 
* edit in graph editor using Figure2recorder.grec, saved as Figure2_nigeria.gph 
* chile sample small, so use a bigger bandwidth
lpoly logsales totalscore if round==1 & chile==1, noscatter ci degree(1) bwidth(0.1) 
* edit in graph editor using Figure2recorder.grec, saved as Figure2_chile.gph 

*** Combine graphs together
graph combine Output\new\Figure2_overall.gph Output\Figure2_bangladesh.gph Output\Figure2_chile.gph Output\Figure2_ghana.gph  Output\Figure2_kenya.gph Output\new\Figure2_mexico.gph Output\Figure2_nigeria.gph Output\Figure2_srilanka.gph, col(4) 
* edited in graph editor with Figure4newcombiner.grec, and saved as Figure2.gph

**** Table 2: Cross-sectional association between business practices and higher sales and profitability
foreach var of varlist paidworkers ownershours inventories capitalstock male ownerage ednyears digitspan ageoffirm raven {
gen `var'_miss=`var'==.
gen `var'_zero=`var'==0
replace `var'=0 if `var'==.
}
gen lnworkers=ln(paidworkers)
replace lnworkers=0 if lnworkers==.
gen lnhours=ln(ownershours)
replace lnhours=0 if lnhours==.
gen lnK=ln(capitalstock)
replace lnK=0 if lnK==.
gen lnInv=ln(inventories)
replace lnInv=0 if lnInv==.

 * detailed industry
 gen detind=detailedindustry
 replace detind=100001 if detind==. & manuf==1
 replace detind=100002 if detind==. & trade==1
 replace detind=100003 if detind==. & services==1
 egen indgroup=group(detind country)
 
 * country specific interactions
 foreach var of varlist  lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero inventories_miss inventories_zero  manuf trade services male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss {
for num 1/7: gen `var'_X=`var' if countrynum==X
for num 1/7: replace `var'_X=0 if `var'_X==.
}

eststo clear
* Labor productivity: only control for labor, industry, and country
areg logsales totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana mexico nigeria  if round==1, r a(indgroup)
eststo table2_1
* Total factor productivity: also control for capital and raw materials
areg logsales totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero inventories_miss inventories_zero chile kenya srilanka bangladesh ghana mexico  nigeria  if round==1, r a(indgroup)
eststo table2_2
* adding other controls for owner and firm characteristics
#delimit ;
areg logsales totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero 
inventories_miss inventories_zero kenya srilanka bangladesh chile ghana mexico  nigeria 
male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss
 if round==1, r a(indgroup);
 #delimit cr
eststo table2_3
* allowing coefficients on all controls to vary with country
 set matsize 1000
  #delimit ;
areg logsales totalscore lnworkers_1 lnworkers_2 lnworkers_3 lnworkers_4 lnworkers_5 lnworkers_6 lnworkers_7
lnhours_1 lnhours_2 lnhours_3 lnhours_4 lnhours_5 lnhours_6 lnhours_7
 paidworkers_miss_1 paidworkers_miss_2 paidworkers_miss_3 paidworkers_miss_4 paidworkers_miss_5 paidworkers_miss_6 paidworkers_miss_7
 paidworkers_zero_1 paidworkers_zero_2 paidworkers_zero_3 paidworkers_zero_4 paidworkers_zero_5 paidworkers_zero_6 paidworkers_zero_7
  ownershours_miss_1  ownershours_miss_2  ownershours_miss_3  ownershours_miss_4  ownershours_miss_5  ownershours_miss_6 ownershours_miss_7
   ownershours_zero_1   ownershours_zero_2   ownershours_zero_3   ownershours_zero_4   ownershours_zero_5   ownershours_zero_6 ownershours_zero_7
   lnK_1 lnK_2 lnK_3 lnK_4 lnK_5 lnK_6 lnInv_1 lnInv_2 lnInv_3 lnInv_4 lnInv_5 lnInv_6 lnInv_7
   capitalstock_miss_1 capitalstock_zero_1  capitalstock_miss_2 capitalstock_zero_2  capitalstock_miss_3 capitalstock_zero_3
    capitalstock_miss_4 capitalstock_zero_4  capitalstock_miss_5 capitalstock_zero_5  capitalstock_miss_6 capitalstock_zero_6 capitalstock_miss_7 capitalstock_zero_7
	inventories_miss_1 inventories_zero_1 inventories_miss_2 inventories_zero_2 inventories_miss_3 inventories_zero_3 inventories_miss_4 inventories_zero_4
	inventories_miss_5 inventories_zero_5 inventories_miss_6 inventories_zero_6 inventories_miss_7 inventories_zero_7
	male_1 ownerage_1 ednyears_1 digitspan_1 ageoffirm_1 raven_1 male_miss_1 ownerage_miss_1 ednyears_miss_1 digitspan_miss_1 ageoffirm_miss_1 raven_miss_1
	male_2 ownerage_2 ednyears_2 digitspan_2 ageoffirm_2 raven_2 male_miss_2 ownerage_miss_2 ednyears_miss_2 digitspan_miss_2 ageoffirm_miss_2 raven_miss_2
	male_3 ownerage_3 ednyears_3 digitspan_3 ageoffirm_3 raven_3 male_miss_3 ownerage_miss_3 ednyears_miss_3 digitspan_miss_3 ageoffirm_miss_3 raven_miss_3
	male_4 ownerage_4 ednyears_4 digitspan_4 ageoffirm_4 raven_4 male_miss_4 ownerage_miss_4 ednyears_miss_4 digitspan_miss_4 ageoffirm_miss_4 raven_miss_4
	male_5 ownerage_5 ednyears_5 digitspan_5 ageoffirm_5 raven_5 male_miss_5 ownerage_miss_5 ednyears_miss_5 digitspan_miss_5 ageoffirm_miss_5 raven_miss_5
	male_6 ownerage_6 ednyears_6 digitspan_6 ageoffirm_6 raven_6 male_miss_6 ownerage_miss_6 ednyears_miss_6 digitspan_miss_6 ageoffirm_miss_6 raven_miss_6
    male_7 ownerage_7 ednyears_7 digitspan_7 ageoffirm_7 raven_7 male_miss_7 ownerage_miss_7 ednyears_miss_7 digitspan_miss_7 ageoffirm_miss_7 raven_miss_7
 chile kenya srilanka bangladesh ghana mexico  nigeria i.indgroup if round==1, r a(indgroup);
 #delimit cr
eststo table2_4
 
 **** Log Profits as the dependent variable
* Labor productivity: only control for labor, industry, and country
areg logprofit totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana mexico nigeria  if round==1, r a(indgroup)
eststo table2_5
* Total factor productivity: also control for capital and raw materials
areg logprofit totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero inventories_miss inventories_zero chile kenya srilanka bangladesh ghana mexico nigeria  if round==1, r a(indgroup)
eststo table2_6
* adding other controls for owner and firm characteristics
#delimit ;
areg logprofit totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero 
inventories_miss inventories_zero kenya srilanka bangladesh chile ghana mexico nigeria 
male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss
 if round==1, r a(indgroup);
 #delimit cr
eststo table2_7
* allowing coefficients on all controls to vary with country
 set matsize 1000
  #delimit ;
areg logprofit totalscore lnworkers_1 lnworkers_2 lnworkers_3 lnworkers_4 lnworkers_5 lnworkers_6 lnworkers_7
lnhours_1 lnhours_2 lnhours_3 lnhours_4 lnhours_5 lnhours_6 lnhours_7
 paidworkers_miss_1 paidworkers_miss_2 paidworkers_miss_3 paidworkers_miss_4 paidworkers_miss_5 paidworkers_miss_6 paidworkers_miss_7
 paidworkers_zero_1 paidworkers_zero_2 paidworkers_zero_3 paidworkers_zero_4 paidworkers_zero_5 paidworkers_zero_6 paidworkers_zero_7
  ownershours_miss_1  ownershours_miss_2  ownershours_miss_3  ownershours_miss_4  ownershours_miss_5  ownershours_miss_6 ownershours_miss_7
   ownershours_zero_1   ownershours_zero_2   ownershours_zero_3   ownershours_zero_4   ownershours_zero_5   ownershours_zero_6 ownershours_zero_7
   lnK_1 lnK_2 lnK_3 lnK_4 lnK_5 lnK_6 lnInv_1 lnInv_2 lnInv_3 lnInv_4 lnInv_5 lnInv_6 lnInv_7
   capitalstock_miss_1 capitalstock_zero_1  capitalstock_miss_2 capitalstock_zero_2  capitalstock_miss_3 capitalstock_zero_3
    capitalstock_miss_4 capitalstock_zero_4  capitalstock_miss_5 capitalstock_zero_5  capitalstock_miss_6 capitalstock_zero_6 capitalstock_miss_7 capitalstock_zero_7
	inventories_miss_1 inventories_zero_1 inventories_miss_2 inventories_zero_2 inventories_miss_3 inventories_zero_3 inventories_miss_4 inventories_zero_4
	inventories_miss_5 inventories_zero_5 inventories_miss_6 inventories_zero_6 inventories_miss_7 inventories_zero_7
	male_1 ownerage_1 ednyears_1 digitspan_1 ageoffirm_1 raven_1 male_miss_1 ownerage_miss_1 ednyears_miss_1 digitspan_miss_1 ageoffirm_miss_1 raven_miss_1
	male_2 ownerage_2 ednyears_2 digitspan_2 ageoffirm_2 raven_2 male_miss_2 ownerage_miss_2 ednyears_miss_2 digitspan_miss_2 ageoffirm_miss_2 raven_miss_2
	male_3 ownerage_3 ednyears_3 digitspan_3 ageoffirm_3 raven_3 male_miss_3 ownerage_miss_3 ednyears_miss_3 digitspan_miss_3 ageoffirm_miss_3 raven_miss_3
	male_4 ownerage_4 ednyears_4 digitspan_4 ageoffirm_4 raven_4 male_miss_4 ownerage_miss_4 ednyears_miss_4 digitspan_miss_4 ageoffirm_miss_4 raven_miss_4
	male_5 ownerage_5 ednyears_5 digitspan_5 ageoffirm_5 raven_5 male_miss_5 ownerage_miss_5 ednyears_miss_5 digitspan_miss_5 ageoffirm_miss_5 raven_miss_5
	male_6 ownerage_6 ednyears_6 digitspan_6 ageoffirm_6 raven_6 male_miss_6 ownerage_miss_6 ednyears_miss_6 digitspan_miss_6 ageoffirm_miss_6 raven_miss_6
    male_7 ownerage_7 ednyears_7 digitspan_7 ageoffirm_7 raven_7 male_miss_7 ownerage_miss_7 ednyears_miss_7 digitspan_miss_7 ageoffirm_miss_7 raven_miss_7
 chile kenya srilanka bangladesh ghana mexico  nigeria i.indgroup if round==1, r a(indgroup);
 #delimit cr
eststo table2_8

#delimit ;
esttab table2_* using Output\new\table2.csv, replace depvar legend label nonumbers nogaps
	drop(_cons paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero capitalstock_miss capitalstock_zero inventories_miss inventories_zero kenya srilanka bangladesh chile ghana mexico nigeria  male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss
	lnworkers_1 lnworkers_2 lnworkers_3 lnworkers_4 lnworkers_5 lnworkers_6 lnworkers_7
lnhours_1 lnhours_2 lnhours_3 lnhours_4 lnhours_5 lnhours_6 lnhours_7
 paidworkers_miss_1 paidworkers_miss_2 paidworkers_miss_3 paidworkers_miss_4 paidworkers_miss_5 paidworkers_miss_6 paidworkers_miss_7
 paidworkers_zero_1 paidworkers_zero_2 paidworkers_zero_3 paidworkers_zero_4 paidworkers_zero_5 paidworkers_zero_6 paidworkers_zero_7
  ownershours_miss_1  ownershours_miss_2  ownershours_miss_3  ownershours_miss_4  ownershours_miss_5  ownershours_miss_6 ownershours_miss_7
   ownershours_zero_1   ownershours_zero_2   ownershours_zero_3   ownershours_zero_4   ownershours_zero_5   ownershours_zero_6 ownershours_zero_7
   lnK_1 lnK_2 lnK_3 lnK_4 lnK_5 lnK_6 lnInv_1 lnInv_2 lnInv_3 lnInv_4 lnInv_5 lnInv_6 lnInv_7
   capitalstock_miss_1 capitalstock_zero_1  capitalstock_miss_2 capitalstock_zero_2  capitalstock_miss_3 capitalstock_zero_3 
    capitalstock_miss_4 capitalstock_zero_4  capitalstock_miss_5 capitalstock_zero_5  capitalstock_miss_6 capitalstock_zero_6 capitalstock_miss_7 capitalstock_zero_7
	inventories_miss_1 inventories_zero_1 inventories_miss_2 inventories_zero_2 inventories_miss_3 inventories_zero_3 inventories_miss_4 inventories_zero_4
	inventories_miss_5 inventories_zero_5 inventories_miss_6 inventories_zero_6 inventories_miss_7 inventories_zero_7
	male_1 ownerage_1 ednyears_1 digitspan_1 ageoffirm_1 raven_1 male_miss_1 ownerage_miss_1 ednyears_miss_1 digitspan_miss_1 ageoffirm_miss_1 raven_miss_1
	male_2 ownerage_2 ednyears_2 digitspan_2 ageoffirm_2 raven_2 male_miss_2 ownerage_miss_2 ednyears_miss_2 digitspan_miss_2 ageoffirm_miss_2 raven_miss_2
	male_3 ownerage_3 ednyears_3 digitspan_3 ageoffirm_3 raven_3 male_miss_3 ownerage_miss_3 ednyears_miss_3 digitspan_miss_3 ageoffirm_miss_3 raven_miss_3
	male_4 ownerage_4 ednyears_4 digitspan_4 ageoffirm_4 raven_4 male_miss_4 ownerage_miss_4 ednyears_miss_4 digitspan_miss_4 ageoffirm_miss_4 raven_miss_4
	male_5 ownerage_5 ednyears_5 digitspan_5 ageoffirm_5 raven_5 male_miss_5 ownerage_miss_5 ednyears_miss_5 digitspan_miss_5 ageoffirm_miss_5 raven_miss_5
	male_6 ownerage_6 ednyears_6 digitspan_6 ageoffirm_6 raven_6 male_miss_6 ownerage_miss_6 ednyears_miss_6 digitspan_miss_6 ageoffirm_miss_6 raven_miss_6 
	male_7 ownerage_7 ednyears_7 digitspan_7 ageoffirm_7 raven_7 male_miss_7 ownerage_miss_7 ednyears_miss_7 digitspan_miss_7 ageoffirm_miss_7 raven_miss_7) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N, fmt(%9.0g) labels("Sample Size" )) 
	title("Table 2: Cross-Sectional Associations") addnotes("""") ;
#delimit cr

**Check that the results are the same is we use log of sales+1/profits+1, to recover the obs with zeros in either of these.

gen logsales_a=log(monthlysales+1)
gen logprofit_a=log(monthlyprofit+1)

areg logsales_a totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana nigeria  if round==1, r a(indgroup)
areg logprofit_a totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana nigeria  if round==1, r a(indgroup)




**** Appendix Table 2: Robustness to Different Ways of Aggregating
* Principal component
pca bp_m1-bp_f8 if round==1
predict scorefactor
* note this has the issue of being missing if one of the variables is missing
* Sum of standardized z-scores
foreach var of varlist bp_m1-bp_f8 {
sum `var' if round==1
gen z_`var'= (`var'-r(mean))/r(sd)
}
egen zscore=rmean(z_bp_m1-z_bp_f8)
* correlations of index with these alternatives
corr totalscore scorefactor zscore if round==1

eststo clear
* Labor productivity: only control for labor, industry, and country
areg logsales totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana nigeria  if round==1 & totalscore~=. & scorefactor~=. & zscore~=., r a(indgroup)
sum totalscore if e(sample)
estadd scalar mean=r(mean)
estadd scalar sd=r(sd)
eststo tableA_1

areg logsales scorefactor lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana nigeria  if round==1 & totalscore~=. & scorefactor~=. & zscore~=., r a(indgroup)
sum scorefactor if e(sample)
estadd scalar mean=r(mean)
estadd scalar sd=r(sd)
eststo tableA_2

areg logsales zscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana nigeria  if round==1 & totalscore~=. & scorefactor~=. & zscore~=., r a(indgroup)
sum zscore if e(sample)
estadd scalar mean=r(mean)
estadd scalar sd=r(sd)
eststo tableA_3

* Full productivity with all controls
#delimit ;
areg logsales totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero 
inventories_miss inventories_zero kenya srilanka bangladesh chile ghana nigeria 
male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss
 if round==1 & totalscore~=. & scorefactor~=. & zscore~=., r a(indgroup);
 #delimit cr
sum totalscore if e(sample)
estadd scalar mean=r(mean)
estadd scalar sd=r(sd)
eststo tableA_4

#delimit ;
areg logsales scorefactor lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero 
inventories_miss inventories_zero kenya srilanka bangladesh chile ghana nigeria 
male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss
 if round==1 & totalscore~=. & scorefactor~=. & zscore~=., r a(indgroup);
 #delimit cr
sum scorefactor if e(sample)
estadd scalar mean=r(mean)
estadd scalar sd=r(sd)
eststo tableA_5

#delimit ;
areg logsales zscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero 
inventories_miss inventories_zero kenya srilanka bangladesh chile ghana nigeria 
male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss
 if round==1 & totalscore~=. & scorefactor~=. & zscore~=., r a(indgroup);
 #delimit cr
sum zscore if e(sample)
estadd scalar mean=r(mean)
estadd scalar sd=r(sd)
eststo tableA_6


#delimit ;
esttab tableA_* using Output\tableA2.csv, replace depvar legend label nonumbers nogaps
	drop(_cons paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana nigeria  inventories_miss inventories_zero capitalstock_miss capitalstock_zero male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean sd, fmt(%9.0g %9.3f %9.3f) labels("Sample Size" "Business Practices Mean" "Business Practices SD" )) 
	title("Table A2: Robustness to Form of Aggregating Business Practices") addnotes("""") ;
#delimit cr


*** Table A3: Results by Country
* Labor Productivity
eststo clear
local i=1
forvalues i=1(1)7 {
areg logsales totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana mexico nigeria  if round==1 & countrynum==`i', r a(indgroup)
eststo tableA3_`i'
}
#delimit ;
esttab tableA3_* using Output\new\tableA3.csv, replace depvar legend label nonumbers nogaps
	drop(_cons paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana mexico nigeria) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N, fmt(%9.0g) labels("Sample Size")) mtitles("Bangladesh" "Chile" "Ghana" "Kenya" "Mexico" "Nigeria" "Sri Lanka")
	title("Table A3: Labor Productivity Association by Country") addnotes("""") ;
#delimit cr

* Total Factor Productivity
eststo clear
local i=1
forvalues i=1(1)7 {
areg logsales totalscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero inventories_miss inventories_zero  chile kenya srilanka bangladesh ghana mexico nigeria if round==1 & countrynum==`i', r a(indgroup)
eststo tableA3b_`i'
}
#delimit ;
esttab tableA3b_* using Output\new\tableA3b.csv, replace depvar legend label nonumbers nogaps
	drop(_cons paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh mexico ghana nigeria  capitalstock_miss capitalstock_zero inventories_miss inventories_zero) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N, fmt(%9.0g) labels("Sample Size")) mtitles("Bangladesh" "Chile" "Ghana" "Kenya" "Nigeria" "Sri Lanka")
	title("Table A3b: Total Factor Productivity Association by Country") addnotes("""") ;
#delimit cr

***** Table 3: Sub-components of Business Practices Score
eststo clear
*** Labor Productivity
areg logsales marketingscore stockscore recordscore planningscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana mexico nigeria   if round==1, r a(indgroup)
eststo table3_1
* Total factor productivity: also control for capital and raw materials
areg logsales marketingscore stockscore recordscore planningscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero inventories_miss inventories_zero chile kenya srilanka bangladesh ghana mexico nigeria   if round==1, r a(indgroup)
eststo table3_2
* adding other controls for owner and firm characteristics
#delimit ;
areg logsales marketingscore stockscore recordscore planningscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero 
inventories_miss inventories_zero kenya srilanka bangladesh chile ghana mexico nigeria  
male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss
 if round==1, r a(indgroup);
 #delimit cr
eststo table3_3
*** Labor Productivity
areg logprofit marketingscore stockscore recordscore planningscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana mexico nigeria   if round==1, r a(indgroup)
eststo table3_4
* Total factor productivity: also control for capital and raw materials
areg logprofit marketingscore stockscore recordscore planningscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero inventories_miss inventories_zero chile kenya srilanka bangladesh ghana mexico nigeria   if round==1, r a(indgroup)
eststo table3_5
* adding other controls for owner and firm characteristics
#delimit ;
areg logprofit marketingscore stockscore recordscore planningscore lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero lnK lnInv capitalstock_miss capitalstock_zero 
inventories_miss inventories_zero kenya srilanka bangladesh chile ghana mexico nigeria  
male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss
 if round==1, r a(indgroup);
 #delimit cr
eststo table3_6


#delimit ;
esttab table3_* using Output\new\table3.csv, replace depvar legend label nonumbers nogaps
	drop(_cons paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero capitalstock_miss capitalstock_zero inventories_miss inventories_zero kenya srilanka bangladesh chile ghana mexico nigeria   male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N, fmt(%9.0g) labels("Sample Size" )) 
	title("Table 3: Cross-Sectional Associations with Index Subcomponents") addnotes("""") ;
#delimit cr


**** Table A4: Individual Practices: Means by Country and Associations with TFP

mat y = J(26,10,.)	
local j=1
foreach var of varlist bp_m1-bp_f8 {
sum `var' if  round==1
mat y[`j',1] = r(mean)
forval x=1/7 {
local k=`x'+1
sum `var' if countrynum==`x' & round==1
mat y[`j',`k'] = r(mean)
}
areg logsales `var' lnworkers lnhours paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero chile kenya srilanka bangladesh ghana mexico nigeria   if round==1, r a(indgroup)
mat y[`j',9]=_b[`var']
mat y[`j',10]=_se[`var']
local j=`j'+1
}
mat rownames y = bp_m1-bp_f8
mat colnames y = "All" "Bangladesh" "Chile" "Ghana" "Kenya" "Mexico" "Nigeria" "Sri Lanka" "Regression" "Std Error"
mat2txt, matrix(y) saving(Output\new\TableA4.xls) replace


**** Table 4: Dynamic Associations - Do Baseline Business Practices Predict Survival and Sales Growth
* Sales Growth - is noisy, so also consider truncated for robustness

foreach var of varlist lnworkers lnhours logsales logprofit lnK lnInv paidworkers_miss paidworkers_zero ownershours_miss ownershours_zero capitalstock_miss capitalstock_zero inventories_miss inventories_zero manuf trade services male ownerage ednyears digitspan ageoffirm raven male_miss ownerage_miss ednyears_miss digitspan_miss ageoffirm_miss raven_miss indgroup{
gen base_`var'=`var' if round==1
egen b_`var'=max(base_`var'), by(firmid country)
}

gen salesgrow=logsales-b_logsales
gen salesgrow_trunc=salesgrow
sum salesgrow if round==2, de
replace salesgrow_trunc=r(p5) if salesgrow<r(p5) & round==2
replace salesgrow_trunc=r(p95) if salesgrow>r(p95) & salesgrow~=. & round==2


* One-year survival rates in Kenya, Nigeria, Sri Lanka
eststo clear
dprobit survival bscore kenya nigeria srilanka b_manuf b_trade b_services if (country=="Kenya" & round==2)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3), r
sum survival if e(sample)
estadd scalar mean=r(mean)
eststo table4_1

dprobit survival bscore b_lnworkers b_paidworkers_miss b_paidworkers_zero b_manuf b_trade b_services  kenya nigeria srilanka if (country=="Kenya" & round==2)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3), r
sum survival if e(sample)
estadd scalar mean=r(mean)
eststo table4_2

dprobit survival bscore b_lnworkers b_paidworkers_miss b_paidworkers_zero b_manuf b_trade b_services b_male b_male_miss b_ownerage b_ownerage_miss b_ednyears b_ednyears_miss b_digitspan b_digitspan_miss b_ageoffirm b_ageoffirm_miss b_raven b_raven_miss kenya nigeria srilanka if (country=="Kenya" & round==2)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3), r
sum survival if e(sample)
estadd scalar mean=r(mean)
eststo table4_3

dprobit survival bscore b_lnworkers b_paidworkers_miss b_paidworkers_zero b_manuf b_trade b_services b_male b_male_miss b_ownerage b_ownerage_miss b_ednyears b_ednyears_miss b_digitspan b_digitspan_miss b_ageoffirm b_ageoffirm_miss b_raven b_raven_miss kenya nigeria srilanka b_logsales b_logprofit if (country=="Kenya" & round==2)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3), r
sum survival if e(sample)
estadd scalar mean=r(mean)
eststo table4_4

* 5.5 year survival rate in Sri Lanka (October 2008 to April 2014)
dprobit survival bscore b_manuf b_trade b_services b_lnworkers b_paidworkers_miss b_paidworkers_zero if round==11, r
sum survival if e(sample)
estadd scalar mean=r(mean)
eststo table4_5

areg salesgrow bscore b_logsales kenya nigeria srilanka  if (country=="Kenya" & round==2)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3), r a(b_indgroup)
sum salesgrow if e(sample)
estadd scalar mean=r(mean)
eststo table4_6

areg salesgrow bscore b_logsales b_lnworkers b_paidworkers_miss b_paidworkers_zero b_manuf b_trade b_services b_male b_male_miss b_ownerage b_ownerage_miss b_ednyears b_ednyears_miss b_digitspan b_digitspan_miss b_ageoffirm b_ageoffirm_miss b_raven b_raven_miss kenya nigeria srilanka  b_logprofit if (country=="Kenya" & round==2)|(country=="Nigeria" & round==2)|(country=="Sri Lanka" & round==3), r a(b_indgroup)
sum salesgrow if e(sample)
estadd scalar mean=r(mean)
eststo table4_7

areg salesgrow bscore b_logsales b_manuf b_trade b_services b_lnworkers b_paidworkers_miss b_paidworkers_zero if round==11, r a(b_indgroup)
sum salesgrow if e(sample)
estadd scalar mean=r(mean)
eststo table4_8

#delimit ;
esttab table4_* using Output\table4.csv, replace depvar legend label nonumbers nogaps margin
	drop(_cons b_paidworkers_miss b_paidworkers_zero kenya srilanka nigeria b_manuf b_trade b_services b_male_miss b_ownerage_miss  b_digitspan_miss b_ageoffirm_miss b_raven_miss) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean, fmt(%9.0g %9.3f) labels("Sample Size" "Mean")) mtitles("Survival" "Survival" "Survival" "Survival" "5.5 Year Survival" "Sales Growth" "Sales Growth" "Sales Growth 5.5 years")
	title("Table 4: Baseline Business Score and Survival and Growth Dynamics") addnotes("""") ;
#delimit cr

**** Table 5: Reconciling with the Experimental Effects
*  Sri Lankan women 
reg totalscore training_treat othertreatment if srilanka==1 & male==0 & round==2, r
* impacts on log sales and log profits taken from de Mel et al. JDE paper

* Sri Lankan men (note business practices not measured in round 2 for this sample)
reg totalscore training_treat othertreatment if srilanka==1 & male==1 & round==3, r
reg logsales training_treat othertreatment if srilanka==1 & male==1 & round==3, r
reg logprofit training_treat othertreatment if srilanka==1 & male==1 & round==3, r

* Kenyan women
reg totalscore training_treat  if kenya==1 & round==2, r
reg logsales training_treat if kenya==1 & round==2, r
reg logprofit training_treat  if kenya==1 & round==2, r



**** Figure 5: Education and Business Practices
sum ednyears, de
lpoly totalscore ednyears if round==1 & ednyears<=20, noscatter ci degree(1) bwidth(5) ylabel(0(0.2)1)
* edit in graph editor saved as Figure3_overall.gph 
lpoly totalscore ednyears if round==1 & kenya==1 & ednyears<=20, noscatter ci degree(1) bwidth(5) ylabel(0(0.2)1)
* edit in graph editor saved as Figure3_kenya.gph 
lpoly totalscore ednyears if round==1 & srilanka==1 & ednyears<=20, noscatter ci degree(1) bwidth(5) ylabel(0(0.2)1)
* edit in graph editor saved as Figure3_srilanka.gph 
lpoly totalscore ednyears if round==1 & bangladesh==1 & ednyears<=20, noscatter ci degree(1) bwidth(5) ylabel(0(0.2)1) 
* edit in graph editor saved as Figure3_bangladesh.gph 
lpoly totalscore ednyears if round==1 & ghana==1 & ednyears<=20, noscatter ci degree(1) bwidth(5) ylabel(0(0.2)1)
* edit in graph editor saved as Figure3_ghana.gph 
lpoly totalscore ednyears if round==1 & mexico==1 & ednyears<=20, noscatter ci degree(1) bwidth(5) ylabel(0(0.2)1) 
* edit in graph editor  saved as Figure3_mexico.gph
lpoly totalscore ednyears if round==1 & nigeria==1 & ednyears<=20, noscatter ci degree(1) bwidth(5) ylabel(0(0.2)1) xlabel(0(5)20)
* edit in graph editor saved as Figure3_nigeria.gph 
* chile sample small, so use a bigger bandwidth
lpoly totalscore ednyears if round==1 & chile==1 & ednyears<=20, noscatter ci degree(1) bwidth(5) ylabel(0(0.2)1) xlabel(0(5)20)
* edit in graph editor saved as Figure3_chile.gph 

*** Combine graphs together
graph combine Output\new\Figure3_overall.gph Output\Figure3_bangladesh.gph Output\Figure3_chile.gph Output\Figure3_ghana.gph  Output\Figure3_kenya.gph Output\new\Figure3_mexico.gph Output\Figure3_nigeria.gph Output\Figure3_srilanka.gph, col(4) 
* edited in graph editor and saved as new\Figure5.gph

**** Table 6: Regressions to show associations with human capital, and second generation

foreach var of varlist startedbusiness father_owned_business mother_owned_business {
gen `var'_miss=`var'==.
gen `var'_0=`var'
replace `var'_0=0 if `var'==.
}

gen workers1=paidworkers>=1 & paidworkers<=4
gen workers2=paidworkers>=5 & paidworkers<=9
gen workers3=paidworkers>=10 & paidworkers<=14
gen workers4=paidworkers>=15 & paidworkers<=20
gen workers5=paidworkers>=21 & paidworkers~=.
gen workers_miss=paidworkers==.

gen compete1=competition2==0
gen compete2=competition2>=1 & competition2<=4
gen compete3=competition2>=5 & competition2<=9
gen compete4=competition2>=10 & competition2<=20
gen compete5=competition2>21 & competition2~=.
gen compete_miss=competition2==.

gen competition3_miss=competition3==.
replace competition3=0 if competition3==.

gen competition4_miss=competition4==.
replace competition4=0 if competition4==.



eststo clear
areg totalscore ednyears digitspan digitspan_miss raven raven_miss male male_miss ownerage ownerage_miss  bangladesh chile ghana kenya mexico nigeria srilanka if round==1, r a(indgroup)
eststo table6_1

areg totalscore father_owned_business_0 father_owned_business_miss mother_owned_business_0 mother_owned_business_miss male male_miss ownerage ownerage_miss  bangladesh chile ghana kenya mexico nigeria srilanka if round==1, r a(indgroup)
eststo table6_2

*areg totalscore compete2 compete3 compete4 compete5 compete_miss male male_miss ownerage ownerage_miss  bangladesh chile ghana kenya mexico nigeria srilanka if round==1, r a(indgroup)
*eststo table6_3

*areg totalscore competition3 competition3_miss male male_miss ownerage ownerage_miss  bangladesh chile ghana kenya mexico nigeria srilanka if round==1, r a(indgroup)
*eststo table6_4

*areg totalscore competition4 competition4_miss male male_miss ownerage ownerage_miss  bangladesh chile ghana kenya mexico nigeria srilanka if round==1, r a(indgroup)
*eststo table6_5

areg totalscore workers1-workers5 workers_miss male male_miss ownerage ownerage_miss  bangladesh chile ghana kenya mexico nigeria srilanka if round==1, r a(indgroup)
eststo table6_6

areg totalscore ednyears digitspan digitspan_miss workers1-workers5 workers_miss raven raven_miss father_owned_business_0 father_owned_business_miss mother_owned_business_0 mother_owned_business_miss male male_miss ownerage ownerage_miss  bangladesh chile ghana kenya mexico nigeria srilanka startedbusiness_0 startedbusiness_miss if round==1, r a(indgroup)
eststo table6_7

#delimit ;
esttab table6_* using Output\new\table6.csv, replace depvar legend label nonumbers nogaps 
	drop(_cons *_miss  bangladesh chile ghana kenya mexico nigeria srilanka) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N mean, fmt(%9.0g %9.3f) labels("Sample Size" "Mean")) 
	title("Table 6: Business Practices and Human Capital, Generation, Competition, and Size") addnotes("""") ;
#delimit cr


************ Figure A1: Are business practices non-linear on performance
gen tscore1=totalscore>=0.1 & totalscore<0.2
gen tscore2=totalscore>=0.2 & totalscore<0.3
gen tscore3=totalscore>=0.3 & totalscore<0.4
gen tscore4=totalscore>=0.4 & totalscore<0.5
gen tscore5=totalscore>=0.5 & totalscore<0.6
gen tscore6=totalscore>=0.6 & totalscore<0.7
gen tscore7=totalscore>=0.7 & totalscore<0.8
gen tscore8=totalscore>=0.8 & totalscore<0.9
gen tscore9=totalscore>=0.9 & totalscore<=1

 set matsize 1000
  #delimit ;
areg logprofit tscore1 tscore2 tscore3 tscore4 tscore5 tscore6 tscore7 tscore8 tscore9 
lnworkers_1 lnworkers_2 lnworkers_3 lnworkers_4 lnworkers_5 lnworkers_6 lnworkers_7
lnhours_1 lnhours_2 lnhours_3 lnhours_4 lnhours_5 lnhours_6 lnhours_7
 paidworkers_miss_1 paidworkers_miss_2 paidworkers_miss_3 paidworkers_miss_4 paidworkers_miss_5 paidworkers_miss_6 paidworkers_miss_7
 paidworkers_zero_1 paidworkers_zero_2 paidworkers_zero_3 paidworkers_zero_4 paidworkers_zero_5 paidworkers_zero_6 paidworkers_zero_7
  ownershours_miss_1  ownershours_miss_2  ownershours_miss_3  ownershours_miss_4  ownershours_miss_5  ownershours_miss_6 ownershours_miss_7
   ownershours_zero_1   ownershours_zero_2   ownershours_zero_3   ownershours_zero_4   ownershours_zero_5   ownershours_zero_6 ownershours_zero_7
   lnK_1 lnK_2 lnK_3 lnK_4 lnK_5 lnK_6 lnInv_1 lnInv_2 lnInv_3 lnInv_4 lnInv_5 lnInv_6 lnInv_7
   capitalstock_miss_1 capitalstock_zero_1  capitalstock_miss_2 capitalstock_zero_2  capitalstock_miss_3 capitalstock_zero_3
    capitalstock_miss_4 capitalstock_zero_4  capitalstock_miss_5 capitalstock_zero_5  capitalstock_miss_6 capitalstock_zero_6 capitalstock_miss_7 capitalstock_zero_7
	inventories_miss_1 inventories_zero_1 inventories_miss_2 inventories_zero_2 inventories_miss_3 inventories_zero_3 inventories_miss_4 inventories_zero_4
	inventories_miss_5 inventories_zero_5 inventories_miss_6 inventories_zero_6 inventories_miss_7 inventories_zero_7
	male_1 ownerage_1 ednyears_1 digitspan_1 ageoffirm_1 raven_1 male_miss_1 ownerage_miss_1 ednyears_miss_1 digitspan_miss_1 ageoffirm_miss_1 raven_miss_1
	male_2 ownerage_2 ednyears_2 digitspan_2 ageoffirm_2 raven_2 male_miss_2 ownerage_miss_2 ednyears_miss_2 digitspan_miss_2 ageoffirm_miss_2 raven_miss_2
	male_3 ownerage_3 ednyears_3 digitspan_3 ageoffirm_3 raven_3 male_miss_3 ownerage_miss_3 ednyears_miss_3 digitspan_miss_3 ageoffirm_miss_3 raven_miss_3
	male_4 ownerage_4 ednyears_4 digitspan_4 ageoffirm_4 raven_4 male_miss_4 ownerage_miss_4 ednyears_miss_4 digitspan_miss_4 ageoffirm_miss_4 raven_miss_4
	male_5 ownerage_5 ednyears_5 digitspan_5 ageoffirm_5 raven_5 male_miss_5 ownerage_miss_5 ednyears_miss_5 digitspan_miss_5 ageoffirm_miss_5 raven_miss_5
	male_6 ownerage_6 ednyears_6 digitspan_6 ageoffirm_6 raven_6 male_miss_6 ownerage_miss_6 ednyears_miss_6 digitspan_miss_6 ageoffirm_miss_6 raven_miss_6
    male_7 ownerage_7 ednyears_7 digitspan_7 ageoffirm_7 raven_7 male_miss_7 ownerage_miss_7 ednyears_miss_7 digitspan_miss_7 ageoffirm_miss_7 raven_miss_7
 chile kenya srilanka bangladesh mexico ghana nigeria  if round==1, r a(indgroup);
 #delimit cr
coefplot, keep(tscore1 tscore2 tscore3 tscore4 tscore5 tscore6 tscore7 tscore8 tscore9)  xtitle("Non-linearities in treatment effect") vertical
* edited with newFigure5recorder.grec, saved as FigA1.gph and FigA1.wmf

